pm4py.evaluation.wf\_net package
================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.evaluation.wf_net.variants

Submodules
----------

pm4py.evaluation.wf\_net.evaluator module
-----------------------------------------

.. automodule:: pm4py.evaluation.wf_net.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.wf_net
   :members:
   :undoc-members:
   :show-inheritance:
